Account class
Account information.
Constructors
- Account(String? uuid, String? name, String? currency, double? availableBalance, bool? isDefault, bool? active, DateTime? createdAt, DateTime? updatedAt, DateTime? deletedAt, String? type, bool? ready, double? holdValue)
- Account constructor
-
Account.fromCBJson(Map<
String, dynamic> json) - Creates an Account from a Coinbase JSON object.
-
Account.fromJson(Map<
String, dynamic> json) - Creates an Account from a JSON object.
Properties
- active → bool?
-
Whether the account is active.
final
- availableBalance → double?
-
The account's available balance.
final
- createdAt → DateTime?
-
The account's creation time.
final
- currency → String?
-
The account's currency.
final
- deletedAt → DateTime?
-
The account's deletion time.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- holdValue → double?
-
The account's hold value.
final
- isDefault → bool?
-
Whether the account is the default account.
final
- name → String?
-
The account's name.
final
- ready → bool?
-
Whether the account is ready.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
The account's type.
final
- updatedAt → DateTime?
-
The account's last update time.
final
- uuid → String?
-
The account's uuid.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts an Account to a JSON object.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited