AvailableBalance class

The available balance for an account.

Constructors

AvailableBalance(double? value, String? currency)
AvailableBalance constructor
AvailableBalance.fromCBJson(Map<String, dynamic> json)
Creates an AvailableBalance from a Coinbase JSON object.

Properties

currency String?
The currency of the available balance.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double?
The value of the available balance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited