Candle class

A candle for a product.

Constructors

Candle({required String start, required String high, required String low, required String open, required String close, required String volume})
Candle constructor
Candle.fromJson(Map<String, dynamic> json)
Creates a Candle from a JSON object.
factory

Properties

close String
The closing price of the candle.
final
hashCode int
The hash code for this object.
no setterinherited
high String
The highest price of the candle.
final
low String
The lowest price of the candle.
final
open String
The opening price of the candle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start String
The start time of the candle.
final
volume String
The volume of the candle.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited