Credential class

A credential for accessing the Coinbase API.

Constructors

Credential({required String apiKeyName, required String privateKeyPEM})
Credential constructor

Properties

apiKeyName String
The name of the API key.
final
hashCode int
The hash code for this object.
no setterinherited
privateKeyPEM String
The private key in PEM format.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited