CurrencyPair class
A representation of a currency pair.
Constructors
- CurrencyPair({required Money userNativeCurrency, required Money rawCurrency})
- CurrencyPair constructor
-
CurrencyPair.fromCBJson(Map<
String, dynamic> json) -
Creates a CurrencyPair from a Coinbase JSON object.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawCurrency → Money
-
The currency pair in the raw currency.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userNativeCurrency → Money
-
The currency pair in the user's native currency.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited