FeeTier class
A fee tier for a user.
Constructors
-
FeeTier({required String pricingTier, required String takerFeeRate, required String makerFeeRate, required String aopFrom, required String aopTo, required List<
VolumeTypesAndRange> volumeTypesAndRange}) - FeeTier constructor
-
FeeTier.fromCBJson(Map<
String, dynamic> json) -
Creates a FeeTier from a Coinbase JSON object.
factory
Properties
- aopFrom → String
-
The start of the average order price range.
final
- aopTo → String
-
The end of the average order price range.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- makerFeeRate → String
-
The maker fee rate.
final
- pricingTier → String
-
The pricing tier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- takerFeeRate → String
-
The taker fee rate.
final
-
volumeTypesAndRange
→ List<
VolumeTypesAndRange> -
The volume types and ranges.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited