Fill class

A fill for an order.

Constructors

Fill(String? entryId, String? tradeId, String? orderId, DateTime? tradeTime, String? tradeType, double? price, double? size, double? commission, String? productId, DateTime? sequenceTimestamp, String? liquidityIndicator, bool? sizeInQuote, String? userId, String? side)
Fill constructor
Fill.fromCBJson(Map<String, dynamic> json)
Creates a Fill from a Coinbase JSON object.
Fill.fromJson(Map<String, dynamic> json)
Creates a Fill from a JSON object.

Properties

commission double?
The commission for the trade.
final
entryId String?
The entry ID.
final
hashCode int
The hash code for this object.
no setterinherited
liquidityIndicator String?
The liquidity indicator.
final
orderId String?
The order ID.
final
price double?
The price of the trade.
final
productId String?
The product ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceTimestamp DateTime?
The sequence timestamp.
final
side String?
The side of the order.
final
size double?
The size of the trade.
final
sizeInQuote bool?
Whether the size is in the quote currency.
final
tradeId String?
The trade ID.
final
tradeTime DateTime?
The time of the trade.
final
tradeType String?
The type of the trade.
final
userId String?
The user ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts a Fill to a JSON object.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited