KeyPermissions class

The permissions for an API key.

Constructors

KeyPermissions({required bool canView, required bool canTrade, required bool canTransfer, required String portfolioUuid, required String portfolioType})
KeyPermissions constructor
KeyPermissions.fromCBJson(Map<String, dynamic> json)
Creates a KeyPermissions from a Coinbase JSON object.
factory

Properties

canTrade bool
Whether the key can trade.
final
canTransfer bool
Whether the key can transfer.
final
canView bool
Whether the key can view.
final
hashCode int
The hash code for this object.
no setterinherited
portfolioType String
The type of the portfolio.
final
portfolioUuid String
The UUID of the portfolio.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited