LimitGTC class
A limit order that is good until canceled.
Constructors
Properties
- baseSize → double?
-
The amount of base currency to spend on the order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limitPrice → double?
-
The price at which to limit the order.
final
- postOnly → bool?
-
Whether the order is post-only.
final
- quoteSize → double?
-
The amount of quote currency to spend on the order.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBJson(
) → Map< String, dynamic> - Converts a LimitGTC to a Coinbase JSON object.
-
toJson(
) → Map< String, dynamic> - Converts a LimitGTC to a JSON object.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited