toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  String all = '{'
      'orderId=$orderId, productId=$productId, userId=$userId, '
      'orderConfiguration=$orderConfiguration, side=$side, '
      'clientOrderId=$clientOrderId, status=$status, '
      'timeInForce=$timeInForce, createdTime=$createdTime, '
      'completionPercentage=$completionPercentage, filledSize=$filledSize, '
      'averageFilledPrice=$averageFilledPrice, fee=$fee, '
      'numberOfFills=$numberOfFills, filledValue=$filledValue, '
      'pendingCancel=$pendingCancel, sizeInQuote=$sizeInQuote, '
      'totalFees=$totalFees, sizeInclusiveOfFees=$sizeInclusiveOfFees, '
      'totalValueAfterFees=$totalValueAfterFees, '
      'triggerStatus=$triggerStatus, orderType=$orderType,'
      'rejectReason=$rejectReason, settled=$settled, '
      'productType=$productType, rejectMessage=$rejectMessage, '
      'cancelMessage=$cancelMessage'
      '}';
  return all;
}