OrderSide enum

The side of the order.

Inheritance
Available extensions

Values

unknownOrderSide → const OrderSide

An unknown order side.

const OrderSide('UNKNOWN_ORDER_SIDE')
buy → const OrderSide

A buy order.

const OrderSide('BUY')
sell → const OrderSide

A sell order.

const OrderSide('SELL')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The String value of the enum.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCB() String
Converts an OrderSide to a Coinbase string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCB(String cb) OrderSide
Creates an OrderSide from a Coinbase string.

Constants

values → const List<OrderSide>
A constant List of the values in this enum, in order of their declaration.