OrderStatus enum
The status of an order.
Values
- unknownOrderStatus → const OrderStatus
-
An unknown order status.
const OrderStatus('UNKNOWN_ORDER_STATUS') - open → const OrderStatus
-
The order is open.
const OrderStatus('OPEN') - filled → const OrderStatus
-
The order is filled.
const OrderStatus('FILLED') - cancelled → const OrderStatus
-
The order is cancelled.
const OrderStatus('CANCELLED') - expired → const OrderStatus
-
The order has expired.
const OrderStatus('EXPIRED') - failed → const OrderStatus
-
The order has failed.
const OrderStatus('FAILED') - pending → const OrderStatus
-
The order is pending.
const OrderStatus('PENDING')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The String value of the enum.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCB(
) → String - Converts an OrderStatus to a Coinbase string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCB(
String cb) → OrderStatus - Creates an OrderStatus from a Coinbase string.
Constants
-
values
→ const List<
OrderStatus> - A constant List of the values in this enum, in order of their declaration.