PerpPosition class

A representation of a perpetual position.

Constructors

PerpPosition({required String productId, required String productUuid, required String symbol, required String assetImageUrl, required Vwap vwap, required String positionSide, required String netSize, required String buyOrderSize, required String sellOrderSize, required String imContribution, required CurrencyPair unrealizedPnl, required CurrencyPair markPrice, required CurrencyPair liquidationPrice, required String leverage, required CurrencyPair imNotional, required CurrencyPair mmNotional, required CurrencyPair positionNotional, required String marginType, required String liquidationBuffer, required String liquidationPercentage, required String assetColor})
PerpPosition constructor
PerpPosition.fromCBJson(Map<String, dynamic> json)
Creates a PerpPosition from a Coinbase JSON object.
factory

Properties

assetColor String
The asset color.
final
assetImageUrl String
The asset image URL.
final
buyOrderSize String
The buy order size.
final
hashCode int
The hash code for this object.
no setterinherited
imContribution String
The IM contribution.
final
imNotional CurrencyPair
The IM notional.
final
leverage String
The leverage.
final
liquidationBuffer String
The liquidation buffer.
final
liquidationPercentage String
The liquidation percentage.
final
liquidationPrice CurrencyPair
The liquidation price.
final
marginType String
The margin type.
final
markPrice CurrencyPair
The mark price.
final
mmNotional CurrencyPair
The MM notional.
final
netSize String
The net size.
final
positionNotional CurrencyPair
The position notional.
final
positionSide String
The position side.
final
productId String
The product ID.
final
productUuid String
The product UUID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellOrderSize String
The sell order size.
final
symbol String
The symbol.
final
unrealizedPnl CurrencyPair
The unrealized PNL.
final
vwap Vwap
The VWAP.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited