toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'PerpPosition{productId: $productId, productUuid: $productUuid, symbol: $symbol, assetImageUrl: $assetImageUrl, vwap: $vwap, positionSide: $positionSide, netSize: $netSize, buyOrderSize: $buyOrderSize, sellOrderSize: $sellOrderSize, imContribution: $imContribution, unrealizedPnl: $unrealizedPnl, markPrice: $markPrice, liquidationPrice: $liquidationPrice, leverage: $leverage, imNotional: $imNotional, mmNotional: $mmNotional, positionNotional: $positionNotional, marginType: $marginType, liquidationBuffer: $liquidationBuffer, liquidationPercentage: $liquidationPercentage, assetColor: $assetColor}';
}