Portfolio class

A portfolio.

Constructors

Portfolio({required String uuid, required String name, required String type, required bool deleted})
Portfolio constructor
Portfolio.fromCBJson(Map<String, dynamic> json)
Creates a Portfolio from a Coinbase JSON object.
factory

Properties

deleted bool
Whether the portfolio is deleted.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the portfolio.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of the portfolio.
final
uuid String
The UUID of the portfolio.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited