PortfolioBalances class
A representation of portfolio balances.
Constructors
- PortfolioBalances({required Money totalBalance, required Money totalFuturesBalance, required Money totalCashEquivalentBalance, required Money totalCryptoBalance, required Money futuresUnrealizedPnl, required Money perpUnrealizedPnl})
- PortfolioBalances constructor
-
PortfolioBalances.fromCBJson(Map<
String, dynamic> json) -
Creates a PortfolioBalances from a Coinbase JSON object.
factory
Properties
- futuresUnrealizedPnl → Money
-
The futures unrealized PNL.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- perpUnrealizedPnl → Money
-
The perpetuals unrealized PNL.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBalance → Money
-
The total balance.
final
- totalCashEquivalentBalance → Money
-
The total cash equivalent balance.
final
- totalCryptoBalance → Money
-
The total crypto balance.
final
- totalFuturesBalance → Money
-
The total futures balance.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited