Product class

A representation of a product.

Constructors

Product({String? productId, double? price, String? pricePercentageChange24h, double? volume24h, String? volumePercentageChange24h, double? baseIncrement, double? quoteIncrement, double? quoteMinSize, double? quoteMaxSize, double? baseMinSize, double? baseMaxSize, String? baseName, String? quoteName, bool? watched, bool? isDisabled, bool? isNew, String? status, bool? cancelOnly, bool? limitOnly, bool? postOnly, bool? tradingDisabled, bool? auctionMode, String? productType, String? quoteCurrencyId, String? baseCurrencyId, Map<String, dynamic>? fcmTradingSessionDetails, double? midMarketPrice, String? alias, List<String>? aliasTo, String? baseDisplaySymbol, String? quoteDisplaySymbol, bool? viewOnly, double? priceIncrement, String? displayName, String? productVenue, double? approximateQuote24hVolume, DateTime? newAt, double? marketCap, Map<String, dynamic>? futureProductDetails, Map<String, dynamic>? predictionMarketProductDetails})
Product constructor
Product.fromCBJson(Map<String, dynamic> json)
Creates a Product from a Coinbase JSON object.
Product.fromJson(Map<String, dynamic> json)
Creates a Product from a JSON object.

Properties

alias String?
The alias for the product.
final
aliasTo List<String>?
The aliases for the product.
final
approximateQuote24hVolume double?
The approximate quote volume over the last 24 hours.
final
auctionMode bool?
Whether the product is in auction mode.
final
baseCurrencyId String?
The base currency ID.
final
baseDisplaySymbol String?
The base display symbol.
final
baseIncrement double?
The base increment.
final
baseMaxSize double?
The maximum base size.
final
baseMinSize double?
The minimum base size.
final
baseName String?
The base name.
final
cancelOnly bool?
Whether the product is cancel-only.
final
displayName String?
The display name.
final
fcmTradingSessionDetails Map<String, dynamic>?
The FCM trading session details.
final
futureProductDetails Map<String, dynamic>?
The future product details.
final
hashCode int
The hash code for this object.
no setterinherited
isDisabled bool?
Whether the product is disabled.
final
isNew bool?
Whether the product is new.
final
limitOnly bool?
Whether the product is limit-only.
final
marketCap double?
The market cap.
final
midMarketPrice double?
The mid-market price.
final
newAt DateTime?
The time the product was created.
final
postOnly bool?
Whether the product is post-only.
final
predictionMarketProductDetails Map<String, dynamic>?
The prediction market product details.
final
price double?
The price of the product.
final
priceIncrement double?
The price increment.
final
pricePercentageChange24h String?
The percentage change in price over the last 24 hours.
final
productId String?
The product ID.
final
productType String?
The type of the product.
final
productVenue String?
The product venue.
final
quoteCurrencyId String?
The quote currency ID.
final
quoteDisplaySymbol String?
The quote display symbol.
final
quoteIncrement double?
The quote increment.
final
quoteMaxSize double?
The maximum quote size.
final
quoteMinSize double?
The minimum quote size.
final
quoteName String?
The quote name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
The status of the product.
final
tradingDisabled bool?
Whether trading is disabled for the product.
final
viewOnly bool?
Whether the product is view-only.
final
volume24h double?
The volume over the last 24 hours.
final
volumePercentageChange24h String?
The percentage change in volume over the last 24 hours.
final
watched bool?
Whether the product is watched.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts a Product to a JSON object.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited