ProductBook class
A representation of a product book.
Constructors
-
ProductBook({required String productId, required List<
PriceLevel> bids, required List<PriceLevel> asks, DateTime? time}) - ProductBook constructor
-
ProductBook.fromJson(Map<
String, dynamic> json) -
Creates a ProductBook from a JSON object.
factory
-
ProductBook.fromMap(Map<
String, dynamic> map) -
Creates a ProductBook from a map.
factory
Properties
-
asks
→ List<
PriceLevel> -
The asks.
final
-
bids
→ List<
PriceLevel> -
The bids.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- productId → String
-
The product ID.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time → DateTime?
-
The time of the book.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited