RejectReason enum

The reason an order was rejected.

Inheritance
Available extensions

Values

rejectReasonUnspecified → const RejectReason

An unspecified reason.

const RejectReason('REJECT_REASON_UNSPECIFIED')
invalidProductId → const RejectReason

The product ID was invalid.

const RejectReason('INVALID_PRODUCT_ID')
invalidOrderType → const RejectReason

The order type was invalid.

const RejectReason('INVALID_ORDER_TYPE')
invalidSide → const RejectReason

The side was invalid.

const RejectReason('INVALID_SIDE')
invalidClientOrderId → const RejectReason

The client order ID was invalid.

const RejectReason('INVALID_CLIENT_ORDER_ID')
invalidSize → const RejectReason

The size was invalid.

const RejectReason('INVALID_SIZE')
invalidPrice → const RejectReason

The price was invalid.

const RejectReason('INVALID_PRICE')
insufficientFunds → const RejectReason

There were insufficient funds.

const RejectReason('INSUFFICIENT_FUNDS')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The String value of the enum.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCB() String
Converts a RejectReason to a Coinbase string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCB(String cb) RejectReason
Creates a RejectReason from a Coinbase string.

Constants

values → const List<RejectReason>
A constant List of the values in this enum, in order of their declaration.