ServerTime class

A representation of the server time.

Constructors

ServerTime(DateTime? iso, num? epochSeconds, num? epochMillis)
ServerTime constructor
ServerTime.fromCBJson(Map<String, dynamic> json)
Creates a ServerTime from a Coinbase JSON object.
factory

Properties

epochMillis num?
The time in epoch milliseconds.
final
epochSeconds num?
The time in epoch seconds.
final
hashCode int
The hash code for this object.
no setterinherited
iso DateTime?
The time in ISO 8601 format.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited