SpotPosition class

A representation of a spot position.

Constructors

SpotPosition({required String asset, required String accountUuid, required num totalBalanceFiat, required num totalBalanceCrypto, required num availableToTradeFiat, required num allocation, required Money costBasis, required String assetImgUrl, required bool isCash, required Money averageEntryPrice, required String assetUuid, required num availableToTradeCrypto, required num unrealizedPnl, required num availableToTransferFiat, required num availableToTransferCrypto, required String assetColor, required String accountType, required num fundingPnl, required num availableToSendFiat, required num availableToSendCrypto})
SpotPosition constructor
SpotPosition.fromCBJson(Map<String, dynamic> json)
Creates a SpotPosition from a Coinbase JSON object.
factory

Properties

accountType String
The account type.
final
accountUuid String
The account UUID.
final
allocation num
The allocation.
final
asset String
The asset.
final
assetColor String
The asset color.
final
assetImgUrl String
The asset image URL.
final
assetUuid String
The asset UUID.
final
availableToSendCrypto num
The available to send balance in crypto.
final
availableToSendFiat num
The available to send balance in fiat.
final
availableToTradeCrypto num
The available to trade balance in crypto.
final
availableToTradeFiat num
The available to trade balance in fiat.
final
availableToTransferCrypto num
The available to transfer balance in crypto.
final
availableToTransferFiat num
The available to transfer balance in fiat.
final
averageEntryPrice Money
The average entry price.
final
costBasis Money
The cost basis.
final
fundingPnl num
The funding PNL.
final
hashCode int
The hash code for this object.
no setterinherited
isCash bool
Whether the asset is cash.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBalanceCrypto num
The total balance in crypto.
final
totalBalanceFiat num
The total balance in fiat.
final
unrealizedPnl num
The unrealized PNL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited