Vwap class

A representation of the volume-weighted average price.

Constructors

Vwap({required Money userNativeCurrency, required Money rawCurrency})
Vwap constructor
Vwap.fromCBJson(Map<String, dynamic> json)
Creates a Vwap from a Coinbase JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
rawCurrency Money
The VWAP in the raw currency.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userNativeCurrency Money
The VWAP in the user's native currency.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited