models library
Classes
- Account
- Account information.
- AvailableBalance
- The available balance for an account.
- Candle
- A candle for a product.
- Credential
- A credential for accessing the Coinbase API.
- CurrencyPair
- A representation of a currency pair.
- FeeTier
- A fee tier for a user.
- Fill
- A fill for an order.
- FuturesPosition
- A representation of a futures position.
- GoodsAndServicesTax
- A goods and services tax.
- Hold
- The hold value for an account.
- KeyPermissions
- The permissions for an API key.
- LimitGTC
- A limit order that is good until canceled.
- LimitGTD
- A limit order that is good until a specific time.
- MarketIOC
- A market order that is immediate or cancel.
- Money
- A representation of money.
- Order
- An order.
- OrderConfiguration
- The configuration for an order.
- PerpPosition
- A representation of a perpetual position.
- Portfolio
- A portfolio.
- PortfolioBalances
- A representation of portfolio balances.
- PortfolioBreakdown
- A representation of a portfolio breakdown.
- PriceLevel
- A representation of a price level.
- Product
- A representation of a product.
- ProductBook
- A representation of a product book.
- ServerTime
- A representation of the server time.
- Signature
- A representation of a signature.
- SpotPosition
- A representation of a spot position.
- StopLimitGTC
- A stop-limit order that is good until canceled.
- StopLimitGTD
- A stop-limit order that is good until a certain time.
- Ticker
- A representation of a ticker.
- Trade
- A representation of a trade.
- TransactionSummary
- A representation of a transaction summary.
- VolumeBreakdown
- A representation of a volume breakdown.
- VolumeTypesAndRange
- A volume type and range.
- Vwap
- A representation of the volume-weighted average price.
Enums
- OrderSide
- The side of the order.
- OrderStatus
- The status of an order.
- OrderType
- The type of an order.
- ProductType
- The type of a product.
- RejectReason
- The reason an order was rejected.
- TimeInForce
- The time in force of an order.
- TriggerStatus
- The status of a trigger.