Account class

Constructors

Account(String? uuid, String? name, String? currency, double? availableBalance, bool? isDefault, bool? active, DateTime? createdAt, DateTime? updatedAt, DateTime? deletedAt, String? type, bool? ready, double? holdValue)
Account.fromCBJson(Map<String, dynamic> json)
Account.fromJson(Map<String, dynamic> json)

Properties

active bool?
final
availableBalance double?
final
createdAt DateTime?
final
currency String?
final
deletedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
holdValue double?
final
isDefault bool?
final
name String?
final
ready bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final
updatedAt DateTime?
final
uuid String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited