Candle class

Constructors

Candle({required String start, required String high, required String low, required String open, required String close, required String volume})
Candle.fromJson(Map<String, dynamic> json)
factory

Properties

close String
final
hashCode int
The hash code for this object.
no setterinherited
high String
final
low String
final
open String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start String
final
volume String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited