Fill class

Constructors

Fill(String? entryId, String? tradeId, String? orderId, DateTime? tradeTime, String? tradeType, double? price, double? size, double? commission, String? productId, DateTime? sequenceTimestamp, String? liquidityIndicator, bool? sizeInQuote, String? userId, String? side)
Fill.fromCBJson(Map<String, dynamic> json)
Fill.fromJson(Map<String, dynamic> json)

Properties

commission double?
final
entryId String?
final
hashCode int
The hash code for this object.
no setterinherited
liquidityIndicator String?
final
orderId String?
final
price double?
final
productId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceTimestamp DateTime?
final
side String?
final
size double?
final
sizeInQuote bool?
final
tradeId String?
final
tradeTime DateTime?
final
tradeType String?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited