FuturesPosition class
A representation of a futures position.
Constructors
- FuturesPosition({required String productId, required String contractSize, required String side, required String amount, required String avgEntryPrice, required String currentPrice, required String unrealizedPnl, required String expiry, required String underlyingAsset, required String assetImgUrl, required String productName, required String venue, required String notionalValue, required String assetColor, required String lastTradedAt, required String rollDate})
- FuturesPosition constructor
-
FuturesPosition.fromCBJson(Map<
String, dynamic> json) -
Creates a FuturesPosition from a Coinbase JSON object.
factory
Properties
- amount → String
-
The amount.
final
- assetColor → String
-
The asset color.
final
- assetImgUrl → String
-
The asset image URL.
final
- avgEntryPrice → String
-
The average entry price.
final
- contractSize → String
-
The contract size.
final
- currentPrice → String
-
The current price.
final
- expiry → String
-
The expiry.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastTradedAt → String
-
The last traded at time.
final
- notionalValue → String
-
The notional value.
final
- productId → String
-
The product ID.
final
- productName → String
-
The product name.
final
- rollDate → String
-
The roll date.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → String
-
The side.
final
- underlyingAsset → String
-
The underlying asset.
final
- unrealizedPnl → String
-
The unrealized PNL.
final
- venue → String
-
The venue.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited