FuturesPosition class

Constructors

FuturesPosition({required String productId, required String contractSize, required String side, required String amount, required String avgEntryPrice, required String currentPrice, required String unrealizedPnl, required String expiry, required String underlyingAsset, required String assetImgUrl, required String productName, required String venue, required String notionalValue, required String assetColor, required String lastTradedAt, required String rollDate})
FuturesPosition.fromCBJson(Map<String, dynamic> json)
factory

Properties

amount String
final
assetColor String
final
assetImgUrl String
final
avgEntryPrice String
final
contractSize String
final
currentPrice String
final
expiry String
final
hashCode int
The hash code for this object.
no setterinherited
lastTradedAt String
final
notionalValue String
final
productId String
final
productName String
final
rollDate String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
side String
final
underlyingAsset String
final
unrealizedPnl String
final
venue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited