KeyPermissions class

Constructors

KeyPermissions({required bool canView, required bool canTrade, required bool canTransfer, required String portfolioUuid, required String portfolioType})
KeyPermissions.fromCBJson(Map<String, dynamic> json)
factory

Properties

canTrade bool
final
canTransfer bool
final
canView bool
final
hashCode int
The hash code for this object.
no setterinherited
portfolioType String
final
portfolioUuid String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited