LimitGTC class

Constructors

LimitGTC(double? quoteSize, double? baseSize, double? limitPrice, bool? postOnly)
LimitGTC.fromCBJson(Map<String, dynamic> json)
LimitGTC.fromJson(Map<String, dynamic> json)

Properties

baseSize double?
final
hashCode int
The hash code for this object.
no setterinherited
limitPrice double?
final
postOnly bool?
final
quoteSize double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBJson() Map<String, dynamic>
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited