MarketIOC class
A market order that is immediate or cancel.
Constructors
- MarketIOC(double? quoteSize, double? baseSize)
- MarketIOC constructor
-
MarketIOC.fromCBJson(Map<
String, dynamic> json) - Creates a MarketIOC from a Coinbase JSON object.
-
MarketIOC.fromJson(Map<
String, dynamic> json) - Creates a MarketIOC from a JSON object.
Properties
- baseSize → double?
-
The amount of base currency to spend on the order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- quoteSize → double?
-
The amount of quote currency to spend on the order.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBJson(
) → Map< String, dynamic> - Converts a MarketIOC to a Coinbase JSON object.
-
toJson(
) → Map< String, dynamic> - Converts a MarketIOC to a JSON object.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited