Order class
An order.
Constructors
- Order(String? orderId, String? productId, String? userId, OrderConfiguration? orderConfiguration, OrderSide? side, String? clientOrderId, OrderStatus? status, TimeInForce? timeInForce, DateTime? createdTime, double? completionPercentage, double? filledSize, double? averageFilledPrice, String? fee, double? numberOfFills, double? filledValue, bool? pendingCancel, bool? sizeInQuote, double? totalFees, bool? sizeInclusiveOfFees, double? totalValueAfterFees, TriggerStatus? triggerStatus, OrderType? orderType, RejectReason? rejectReason, bool? settled, ProductType? productType, String? rejectMessage, String? cancelMessage)
- Order constructor
-
Order.fromCBJson(Map<
String, dynamic> json) - Creates an Order from a Coinbase JSON object.
-
Order.fromJson(Map<
String, dynamic> json) - Creates an Order from a JSON object.
Properties
- averageFilledPrice → double?
-
The average filled price of the order.
final
- cancelMessage → String?
-
The cancel message.
final
- clientOrderId → String?
-
The client order ID.
final
- completionPercentage → double?
-
The completion percentage of the order.
final
- createdTime → DateTime?
-
The time the order was created.
final
- fee → String?
-
The fee for the order.
final
- filledSize → double?
-
The filled size of the order.
final
- filledValue → double?
-
The filled value of the order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- numberOfFills → double?
-
The number of fills for the order.
final
- orderConfiguration → OrderConfiguration?
-
The order configuration.
final
- orderId → String?
-
The order ID.
final
- orderType → OrderType?
-
The type of the order.
final
- pendingCancel → bool?
-
Whether the order is pending cancellation.
final
- productId → String?
-
The product ID.
final
- productType → ProductType?
-
The product type.
final
- rejectMessage → String?
-
The reject message.
final
- rejectReason → RejectReason?
-
The reason the order was rejected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settled → bool?
-
Whether the order is settled.
final
- side → OrderSide?
-
The side of the order.
final
- sizeInclusiveOfFees → bool?
-
Whether the size is inclusive of fees.
final
- sizeInQuote → bool?
-
Whether the size is in the quote currency.
final
- status → OrderStatus?
-
The status of the order.
final
- timeInForce → TimeInForce?
-
The time in force for the order.
final
- totalFees → double?
-
The total fees for the order.
final
- totalValueAfterFees → double?
-
The total value after fees.
final
- triggerStatus → TriggerStatus?
-
The trigger status of the order.
final
- userId → String?
-
The user ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBJson(
) → Map< String, dynamic> - Converts an Order to a Coinbase JSON object.
-
toJson(
) → Map< String, dynamic> - Converts an Order to a JSON object.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited