Order class

Constructors

Order(String? orderId, String? productId, String? userId, OrderConfiguration? orderConfiguration, String? side, String? clientOrderId, String? status, String? timeInForce, DateTime? createdTime, double? completionPercentage, double? filledSize, double? averageFilledPrice, String? fee, double? numberOfFills, double? filledValue, bool? pendingCancel, bool? sizeInQuote, double? totalFees, bool? sizeInclusiveOfFees, double? totalValueAfterFees, String? triggerStatus, String? orderType, String? rejectReason, bool? settled, String? productType, String? rejectMessage, String? cancelMessage)
Order.fromCBJson(Map<String, dynamic> json)
Order.fromJson(Map<String, dynamic> json)

Properties

averageFilledPrice double?
final
cancelMessage String?
final
clientOrderId String?
final
completionPercentage double?
final
createdTime DateTime?
final
fee String?
final
filledSize double?
final
filledValue double?
final
hashCode int
The hash code for this object.
no setterinherited
numberOfFills double?
final
orderConfiguration OrderConfiguration?
final
orderId String?
final
orderType String?
final
pendingCancel bool?
final
productId String?
final
productType String?
final
rejectMessage String?
final
rejectReason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settled bool?
final
side String?
final
sizeInclusiveOfFees bool?
final
sizeInQuote bool?
final
status String?
final
timeInForce String?
final
totalFees double?
final
totalValueAfterFees double?
final
triggerStatus String?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBJson() Map<String, dynamic>
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited