OrderConfiguration class

The configuration for an order.

Constructors

OrderConfiguration(LimitGTC? limitGTC, MarketIOC? marketIOC, LimitGTD? limitGTD, StopLimitGTC? stopLimitGTC, StopLimitGTD? stopLimitGTD)
OrderConfiguration constructor
OrderConfiguration.fromCBJson(Map<String, dynamic> json)
Creates an OrderConfiguration from a Coinbase JSON object.
OrderConfiguration.fromJson(Map<String, dynamic> json)
Creates an OrderConfiguration from a JSON object.

Properties

hashCode int
The hash code for this object.
no setterinherited
limitGTC LimitGTC?
A limit order that is good until canceled.
final
limitGTD LimitGTD?
A limit order that is good until a specific time.
final
marketIOC MarketIOC?
A market order that is immediate or cancel.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopLimitGTC StopLimitGTC?
A stop limit order that is good until canceled.
final
stopLimitGTD StopLimitGTD?
A stop limit order that is good until a specific time.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBJson() Map<String, dynamic>
Converts an OrderConfiguration to a Coinbase JSON object.
toJson() Map<String, dynamic>
Converts an OrderConfiguration to a JSON object.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited