OrderConfiguration class
Constructors
- OrderConfiguration(LimitGTC? limitGTC, MarketIOC? marketIOC, LimitGTD? limitGTD, StopLimitGTC? stopLimitGTC, StopLimitGTD? stopLimitGTD)
-
OrderConfiguration.fromCBJson(Map<
String, dynamic> json) -
OrderConfiguration.fromJson(Map<
String, dynamic> json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limitGTC → LimitGTC?
-
final
- limitGTD → LimitGTD?
-
final
- marketIOC → MarketIOC?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopLimitGTC → StopLimitGTC?
-
final
- stopLimitGTD → StopLimitGTD?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBJson(
) → Map< String, dynamic> -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited