PortfolioBalances class
Constructors
- PortfolioBalances({required Money totalBalance, required Money totalFuturesBalance, required Money totalCashEquivalentBalance, required Money totalCryptoBalance, required Money futuresUnrealizedPnl, required Money perpUnrealizedPnl})
-
PortfolioBalances.fromCBJson(Map<
String, dynamic> json) -
factory
Properties
- futuresUnrealizedPnl → Money
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- perpUnrealizedPnl → Money
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBalance → Money
-
final
- totalCashEquivalentBalance → Money
-
final
- totalCryptoBalance → Money
-
final
- totalFuturesBalance → Money
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited