PortfolioBreakdown class
Constructors
-
PortfolioBreakdown({required Portfolio portfolio, required PortfolioBalances portfolioBalances, required List<
SpotPosition> spotPositions, required List<PerpPosition> perpPositions, required List<FuturesPosition> futuresPositions}) -
PortfolioBreakdown.fromCBJson(Map<
String, dynamic> json) -
factory
Properties
-
futuresPositions
→ List<
FuturesPosition> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
perpPositions
→ List<
PerpPosition> -
final
- portfolio → Portfolio
-
final
- portfolioBalances → PortfolioBalances
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spotPositions
→ List<
SpotPosition> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited