Product class

Constructors

Product({String? productId, double? price, String? pricePercentageChange24h, double? volume24h, String? volumePercentageChange24h, double? baseIncrement, double? quoteIncrement, double? quoteMinSize, double? quoteMaxSize, double? baseMinSize, double? baseMaxSize, String? baseName, String? quoteName, bool? watched, bool? isDisabled, bool? isNew, String? status, bool? cancelOnly, bool? limitOnly, bool? postOnly, bool? tradingDisabled, bool? auctionMode, String? productType, String? quoteCurrencyId, String? baseCurrencyId, Map<String, dynamic>? fcmTradingSessionDetails, double? midMarketPrice, String? alias, List<String>? aliasTo, String? baseDisplaySymbol, String? quoteDisplaySymbol, bool? viewOnly, double? priceIncrement, String? displayName, String? productVenue, double? approximateQuote24hVolume, DateTime? newAt, double? marketCap, Map<String, dynamic>? futureProductDetails, Map<String, dynamic>? predictionMarketProductDetails})
Product.fromCBJson(Map<String, dynamic> json)
Product.fromJson(Map<String, dynamic> json)

Properties

alias String?
final
aliasTo List<String>?
final
approximateQuote24hVolume double?
final
auctionMode bool?
final
baseCurrencyId String?
final
baseDisplaySymbol String?
final
baseIncrement double?
final
baseMaxSize double?
final
baseMinSize double?
final
baseName String?
final
cancelOnly bool?
final
displayName String?
final
fcmTradingSessionDetails Map<String, dynamic>?
final
futureProductDetails Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
isDisabled bool?
final
isNew bool?
final
limitOnly bool?
final
marketCap double?
final
midMarketPrice double?
final
newAt DateTime?
final
postOnly bool?
final
predictionMarketProductDetails Map<String, dynamic>?
final
price double?
final
priceIncrement double?
final
pricePercentageChange24h String?
final
productId String?
final
productType String?
final
productVenue String?
final
quoteCurrencyId String?
final
quoteDisplaySymbol String?
final
quoteIncrement double?
final
quoteMaxSize double?
final
quoteMinSize double?
final
quoteName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
tradingDisabled bool?
final
viewOnly bool?
final
volume24h double?
final
volumePercentageChange24h String?
final
watched bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited