ProductBook class
Constructors
-
ProductBook({required String productId, required List<
PriceLevel> bids, required List<PriceLevel> asks}) -
ProductBook.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
asks
→ List<
PriceLevel> -
final
-
bids
→ List<
PriceLevel> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- productId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited