ServerTime class

Constructors

ServerTime(DateTime? iso, num? epochSeconds, num? epochMillis)
ServerTime.fromCBJson(Map<String, dynamic> json)
factory

Properties

epochMillis num?
final
epochSeconds num?
final
hashCode int
The hash code for this object.
no setterinherited
iso DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited