StopLimitGTC class
A stop-limit order that is good until canceled.
Constructors
- StopLimitGTC(double? quoteSize, double? baseSize, double? limitPrice, double? stopPrice, StopDirection? stopDirection)
- StopLimitGTC constructor
-
StopLimitGTC.fromCBJson(Map<
String, dynamic> json) - Creates a StopLimitGTC from a Coinbase JSON object.
-
StopLimitGTC.fromJson(Map<
String, dynamic> json) - Creates a StopLimitGTC from a JSON object.
Properties
- baseSize → double?
-
The amount of base currency to spend on the order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limitPrice → double?
-
The price at which to limit the order.
final
- quoteSize → double?
-
The amount of quote currency to spend on the order.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopDirection → StopDirection?
-
The direction of the stop.
final
- stopPrice → double?
-
The price at which to stop the order.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBJson(
) → Map< String, dynamic> - Converts a StopLimitGTC to a Coinbase JSON object.
-
toJson(
) → Map< String, dynamic> - Converts a StopLimitGTC to a JSON object.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited