StopLimitGTD class
A stop-limit order that is good until a certain time.
Constructors
- StopLimitGTD(double? quoteSize, double? baseSize, double? limitPrice, double? stopPrice, DateTime? endTime, StopDirection? stopDirection)
- StopLimitGTD constructor
-
StopLimitGTD.fromCBJson(Map<
String, dynamic> json) - Creates a StopLimitGTD from a Coinbase JSON object.
-
StopLimitGTD.fromJson(Map<
String, dynamic> json) - Creates a StopLimitGTD from a JSON object.
Properties
- baseSize → double?
-
The amount of base currency to spend on the order.
final
- endTime → DateTime?
-
The time at which the order will be canceled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limitPrice → double?
-
The price at which to limit the order.
final
- quoteSize → double?
-
The amount of quote currency to spend on the order.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopDirection → StopDirection?
-
The direction of the stop.
final
- stopPrice → double?
-
The price at which to stop the order.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBJson(
) → Map< String, dynamic> - Converts a StopLimitGTD to a Coinbase JSON object.
-
toJson(
) → Map< String, dynamic> - Converts a StopLimitGTD to a JSON object.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited