StopLimitGTD class
Constructors
- StopLimitGTD(double? quoteSize, double? baseSize, double? limitPrice, double? stopPrice, DateTime? endTime, String? stopDirection)
-
StopLimitGTD.fromCBJson(Map<
String, dynamic> json) -
StopLimitGTD.fromJson(Map<
String, dynamic> json)
Properties
- baseSize → double?
-
final
- endTime → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limitPrice → double?
-
final
- quoteSize → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopDirection → String?
-
final
- stopPrice → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBJson(
) → Map< String, dynamic> -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited