Ticker class
A representation of a ticker.
Constructors
Properties
- bestAsk → double?
-
The best ask for the ticker.
final
- bestBid → double?
-
The best bid for the ticker.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trades
→ List<
Trade> ? -
The trades for the ticker.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited