TimeInForce enum
The time in force of an order.
Values
- unknownTimeInForce → const TimeInForce
-
An unknown time in force.
const TimeInForce('UNKNOWN_TIME_IN_FORCE') - goodUntilCancelled → const TimeInForce
-
The order is good until cancelled.
const TimeInForce('GOOD_UNTIL_CANCELLED') - goodUntilDateTime → const TimeInForce
-
The order is good until a specific date and time.
const TimeInForce('GOOD_UNTIL_DATE_TIME') - immediateOrCancel → const TimeInForce
-
The order is immediate or cancel.
const TimeInForce('IMMEDIATE_OR_CANCEL') - fillOrKill → const TimeInForce
-
The order is fill or kill.
const TimeInForce('FILL_OR_KILL')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The String value of the enum.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCB(
) → String - Converts a TimeInForce to a Coinbase string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCB(
String cb) → TimeInForce - Creates a TimeInForce from a Coinbase string.
Constants
-
values
→ const List<
TimeInForce> - A constant List of the values in this enum, in order of their declaration.