Trade class
A representation of a trade.
Constructors
- Trade(String? tradeId, String? productId, double? price, double? size, DateTime? time, String? side, double? bid, double? ask)
- Trade constructor
-
Trade.fromCBJson(Map<
String, dynamic> json) - Creates a Trade from a Coinbase JSON object.
-
Trade.fromJson(Map<
String, dynamic> json) - Creates a Trade from a JSON object.
Properties
- ask → double?
-
The ask price at the time of the trade.
final
- bid → double?
-
The bid price at the time of the trade.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- price → double?
-
The price of the trade.
final
- productId → String?
-
The product ID.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → String?
-
The side of the trade.
final
- size → double?
-
The size of the trade.
final
- time → DateTime?
-
The time of the trade.
final
- tradeId → String?
-
The trade ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBJson(
) → Map< String, dynamic> - Converts a Trade to a Coinbase JSON object.
-
toJson(
) → Map< String, dynamic> - Converts a Trade to a JSON object.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited