Trade class
Constructors
Properties
- ask → double?
-
final
- bid → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- price → double?
-
final
- productId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → String?
-
final
- size → double?
-
final
- time → DateTime?
-
final
- tradeId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBJson(
) → Map< String, dynamic> -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited