TransactionSummary class
A representation of a transaction summary.
Constructors
-
TransactionSummary({required num totalVolume, required num totalFees, required FeeTier feeTier, required num? marginRate, GoodsAndServicesTax? goodsAndServicesTax, required num advancedTradeOnlyVolume, required num advancedTradeOnlyFees, required num coinbaseProVolume, required num coinbaseProFees, required String totalBalance, required List<
VolumeBreakdown> volumeBreakdown}) - TransactionSummary constructor
-
TransactionSummary.fromCBJson(Map<
String, dynamic> json) -
Creates a TransactionSummary from a Coinbase JSON object.
factory
Properties
- advancedTradeOnlyFees → num
-
The advanced trade only fees.
final
- advancedTradeOnlyVolume → num
-
The advanced trade only volume.
final
- coinbaseProFees → num
-
The Coinbase Pro fees.
final
- coinbaseProVolume → num
-
The Coinbase Pro volume.
final
- feeTier → FeeTier
-
The fee tier.
final
- goodsAndServicesTax → GoodsAndServicesTax?
-
The goods and services tax.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- marginRate → num?
-
The margin rate.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBalance → String
-
The total balance.
final
- totalFees → num
-
The total fees.
final
- totalVolume → num
-
The total volume.
final
-
volumeBreakdown
→ List<
VolumeBreakdown> -
The volume breakdown.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited