TransactionSummary class

Constructors

TransactionSummary({required num totalVolume, required num totalFees, required FeeTier feeTier, required num? marginRate, GoodsAndServicesTax? goodsAndServicesTax, required num advancedTradeOnlyVolume, required num advancedTradeOnlyFees, required num coinbaseProVolume, required num coinbaseProFees, required String totalBalance, required List<VolumeBreakdown> volumeBreakdown})
TransactionSummary.fromCBJson(Map<String, dynamic> json)
factory

Properties

advancedTradeOnlyFees num
final
advancedTradeOnlyVolume num
final
coinbaseProFees num
final
coinbaseProVolume num
final
feeTier FeeTier
final
goodsAndServicesTax GoodsAndServicesTax?
final
hashCode int
The hash code for this object.
no setterinherited
marginRate num?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBalance String
final
totalFees num
final
totalVolume num
final
volumeBreakdown List<VolumeBreakdown>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited