TriggerStatus enum
The status of a trigger.
Values
- unknownTriggerStatus → const TriggerStatus
-
An unknown trigger status.
const TriggerStatus('UNKNOWN_TRIGGER_STATUS') - invalidOrderType → const TriggerStatus
-
An invalid order type.
const TriggerStatus('INVALID_ORDER_TYPE') - stopPending → const TriggerStatus
-
A stop order is pending.
const TriggerStatus('STOP_PENDING') - stopTriggered → const TriggerStatus
-
A stop order has been triggered.
const TriggerStatus('STOP_TRIGGERED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The String value of the enum.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCB(
) → String - Converts a TriggerStatus to a Coinbase string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCB(
String cb) → TriggerStatus - Creates a TriggerStatus from a Coinbase string.
Constants
-
values
→ const List<
TriggerStatus> - A constant List of the values in this enum, in order of their declaration.