Vwap class

Constructors

Vwap({required Money userNativeCurrency, required Money rawCurrency})
Vwap.fromCBJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
rawCurrency Money
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userNativeCurrency Money
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited